module VueCompiler
  module Node
    class Program
      attr_reader :children, :comments

      def initialize(children, comments = [])
        @children = children
        @comments = comments
      end
    end

    class Comment
      attr_reader :body

      def initialize(body)
        @body = body
      end
    end

    class Element
      attr_reader :name, :attributes, :children

      def initialize(name, attributes = [], children = [])
        @name = name
        @attributes = attributes
        @children = children
      end
    end

    class Text
      attr_reader :content

      def initialize(content)
        @content = content
      end
    end

    class Interpolation
      attr_reader :expression

      def initialize(expression)
        @expression = expression
      end
    end

    class Attribute
      attr_reader :name, :value

      def initialize(name, value)
        @name = name
        @value = value
      end
    end

    class AttributeName
      attr_reader :name

      def initialize(name)
        @name = name
      end
    end

    class Directive
      attr_reader :name, :argument, :shorthand

      def initialize(name, argument, shorthand = false)
        @name = name
        @argument = argument
        @shorthand = shorthand
      end
    end

    class AttributeValue
      attr_reader :value

      def initialize(value)
        @value = value
      end
    end

    class TemplateBlock
      attr_reader :body

      def initialize(body)
        @body = body
      end
    end

    class ScriptBlock
      attr_reader :content, :lang

      def initialize(content, lang = 'js')
        @content = content
        @lang = lang
      end
    end

    class StyleBlock
      attr_reader :content, :lang, :scoped

      def initialize(content, lang = 'css', scoped = false)
        @content = content
        @lang = lang
        @scoped = scoped
      end
    end
  end
end
